require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_dnsserversettinglegacy',
  dscmeta_resource_friendly_name: 'DnsServerSettingLegacy',
  dscmeta_resource_name: 'DSC_DnsServerSettingLegacy',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'DnsServerDsc',
  dscmeta_module_version: '3.0.0',
  docs: 'The DSC DnsServerSettingLegacy resource type.
         Automatically generated from version 3.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_loglevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Indicates which policies are activated in the Event Viewer system log.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_noforwarderrecursion: {
      type: 'Optional[Boolean]',
      desc: 'TRUE if the DNS server does not use recursion when name-resolution through forwarders fails.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_dnsserver: {
      type: 'String',
      desc: "Specifies the DNS server to connect to, or use 'localhost' for the current node.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disjointnets: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether the default port binding for a socket used to send queries to remote DNS Servers can be overridden.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    ensurable: {
      type: 'Boolean[false]',
      desc: 'Default attribute added to all dsc types without an ensure property. This resource is not ensurable.',
      default: false,

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
